@@ -12,19 +12,10 @@ pub struct nsID__bindgen_vtable {
 pub struct nsID {
     pub vtable_: *const nsID__bindgen_vtable,
 }
-#[test]
-fn bindgen_test_layout_nsID() {
-    assert_eq!(
-        ::std::mem::size_of::<nsID>(),
-        8usize,
-        concat!("Size of: ", stringify!(nsID)),
-    );
-    assert_eq!(
-        ::std::mem::align_of::<nsID>(),
-        8usize,
-        concat!("Alignment of ", stringify!(nsID)),
-    );
-}
+const _: () = {
+    ["Size of nsID"][::std::mem::size_of::<nsID>() - 8usize];
+    ["Alignment of nsID"][::std::mem::align_of::<nsID>() - 8usize];
+};
 impl Default for nsID {
     fn default() -> Self {
         let mut s = ::std::mem::MaybeUninit::<Self>::uninit();
